@@ -1,18 +1,21 @@
 Measure.R2VS <-
 function(biloci,V,struc){
-
+CALC=TRUE
 M.r2vs		=	NA
 if (any(is.na(biloci)==TRUE)){
-
-						ligne		=	na.action(na.omit(biloci))
+			ligne		=	na.action(na.omit(biloci))
+#less than 5 non-missing data
+CALC=( length(ligne)<=(nrow(biloci)-5) )
+  if(CALC==TRUE){
 						biloci		=	biloci[-ligne,]
 						struc		=	struc[-ligne,]
 						V		=	V[-ligne,-ligne]
 
-			
+		}
 
 				}
 
+if(CALC==TRUE){
 		V_inv		=	Inv.proj.matrix.sdp(V) 
 		rownames(V_inv)	=	rownames(V)
 		colnames(V_inv)	=	colnames(V)
@@ -23,7 +26,7 @@ if (any(is.na(biloci)==TRUE)){
 		MAT		=	DATA-FACT%*%DATA
 		SIG		=	t(MAT)%*%V_inv%*%MAT
 
-		inv_sig_struc	=	solve(SIG[-c(1,2),-c(1,2)])	
+		inv_sig_struc	=	Inv.proj.matrix.sdp(SIG[-c(1,2),-c(1,2)])	
 		sig_l1_struc	=	SIG[1,-c(1,2)]			
 		sig_l2_struc	=	SIG[2,-c(1,2)]			
 		num_r2vs	=      (SIG[1,2]-(sig_l1_struc%*%inv_sig_struc%*%sig_l2_struc))^2
@@ -33,8 +36,7 @@ if (any(is.na(biloci)==TRUE)){
 ifelse ((denom11_r2vs<0.0000001)|(denom22_r2vs<0.0000001),M.r2vs<-0,M.r2vs<-num_r2vs/(denom11_r2vs*denom22_r2vs) )
 
 as.numeric(M.r2vs)
-
-		
+              }
+M.r2vs		
 
 }
-
